@@ -117,7 +117,7 @@ void clamd_virus_found_cb(int fd, const char *virname, void *ctx)
     
     if (d == NULL)
         return;
-    if (!(d->options & CL_SCAN_ALLMATCHES) && !(d->options & CL_SCAN_HEURISTIC_PRECEDENCE))
+    if (!(d->options->general & CL_SCAN_GENERAL_ALLMATCHES) && !(d->options->general & CL_SCAN_GENERAL_HEURISTIC_PRECEDENCE))
         return;
     if (virname == NULL)
         return;
@@ -277,7 +277,7 @@ int scan_callback(STATBUF *sb, char *filename, const char *msg, enum cli_ftw_rea
 
     if (ret == CL_VIRUS) {
 
-         if (scandata->options & CL_SCAN_ALLMATCHES || (scandata->infected && scandata->options & CL_SCAN_HEURISTIC_PRECEDENCE)) {
+         if (scandata->options->general & CL_SCAN_GENERAL_ALLMATCHES || (scandata->infected && scandata->options->general & CL_SCAN_GENERAL_HEURISTIC_PRECEDENCE)) {
             if(optget(scandata->opts, "PreludeEnable")->enabled){
                 prelude_logging(filename, virname, context.virhash, context.virsize);
             }
@@ -353,12 +353,17 @@ int scan_pathchk(const char *path, struct cli_ftw_cbdata *data)
     return 0;
 }
 
-int scanfd(const client_conn_t *conn, unsigned long int *scanned,
-	   const struct cl_engine *engine,
-	   unsigned int options, const struct optstruct *opts, int odesc, int stream)
+int scanfd(
+	const client_conn_t *conn,
+	unsigned long int *scanned,
+	const struct cl_engine *engine,
+	struct cl_scan_options *options,
+	const struct optstruct *opts,
+	int odesc,
+	int stream)
 {
     int ret, fd = conn->scanfd;
-	const char *virname;
+	const char *virname = NULL;
 	STATBUF statbuf;
 	struct cb_context context;
 	char fdstr[32];
@@ -388,8 +393,8 @@ int scanfd(const client_conn_t *conn, unsigned long int *scanned,
 	thrmgr_setactivetask(fdstr, NULL);
 	context.filename = fdstr;
 	context.virsize = 0;
-        context.scandata = NULL;
-	ret = cl_scandesc_callback(fd, &virname, scanned, engine, options, &context);
+	context.scandata = NULL;
+	ret = cl_scandesc_callback(fd, conn->filename, &virname, scanned, engine, options, &context);
 	thrmgr_setactivetask(NULL, NULL);
 
 	if (thrmgr_group_need_terminate(conn->group)) {
@@ -418,14 +423,20 @@ int scanfd(const client_conn_t *conn, unsigned long int *scanned,
 	return ret;
 }
 
-int scanstream(int odesc, unsigned long int *scanned, const struct cl_engine *engine, unsigned int options, const struct optstruct *opts, char term)
+int scanstream(
+	int odesc,
+	unsigned long int *scanned,
+	const struct cl_engine *engine,
+	struct cl_scan_options *options,
+	const struct optstruct *opts,
+	char term)
 {
 	int ret, sockfd, acceptd;
 	int tmpd, bread, retval, firsttimeout, timeout, btread;
 	unsigned int port = 0, portscan, min_port, max_port;
 	unsigned long int quota = 0, maxsize = 0;
 	short bound = 0;
-	const char *virname;
+	const char *virname = NULL;
 	char buff[FILEBUFF];
 	char peer_addr[32];
 	struct cb_context context;
@@ -552,13 +563,13 @@ int scanstream(int odesc, unsigned long int *scanned, const struct cl_engine *en
     }
 
     if(retval == 1) {
-	lseek(tmpd, 0, SEEK_SET);
-	thrmgr_setactivetask(peer_addr, NULL);
-	context.filename = peer_addr;
-	context.virsize = 0;
-        context.scandata = NULL;
-	ret = cl_scandesc_callback(tmpd, &virname, scanned, engine, options, &context);
-	thrmgr_setactivetask(NULL, NULL);
+		lseek(tmpd, 0, SEEK_SET);
+		thrmgr_setactivetask(peer_addr, NULL);
+		context.filename = peer_addr;
+		context.virsize = 0;
+		context.scandata = NULL;
+		ret = cl_scandesc_callback(tmpd, tmpname, &virname, scanned, engine, options, &context);
+		thrmgr_setactivetask(NULL, NULL);
     } else {
     	ret = -1;
     }
