@@ -25,7 +25,6 @@
 #include <sys/types.h>
 
 #include "clamav.h"
-#include "cltypes.h"
 #include "fmap.h"
 
 #define CL_FILE_MBUFF_SIZE 1024
@@ -116,6 +115,7 @@ typedef enum {
     CL_TYPE_XML_HWP,
     CL_TYPE_HWPOLE2,
     CL_TYPE_MHTML,
+    CL_TYPE_LNK,
 
     CL_TYPE_OTHER, /* on-the-fly, used for target 14 (OTHER) */
     CL_TYPE_IGNORED /* please don't add anything below */
